@@ -6,11 +6,12 @@ from functools import partial, wraps
 from hashlib import sha256
 import inspect
 from pathlib import Path
+import pickle
 from sqlite3 import connect, Connection
 from textwrap import dedent
 from time import time
 from threading import Lock as SyncLock
-from typing import Any, Callable, Dict, Hashable, Mapping, Optional, Tuple, Type, Union
+from typing import Any, Callable, Hashable, Mapping, Optional, Tuple, Type, Union
 from weakref import finalize, WeakSet
 
 
@@ -58,22 +59,12 @@ class _MemoizeBase:
     keygen: Optional[Keygen]
     size: Optional[int]
 
-    db_eval_types: Optional[Dict[str, Any]] = field(init=False, default=None, hash=False)
     expire_order: OrderedDict = field(init=False, default_factory=OrderedDict, hash=False)
     memos: OrderedDict = field(init=False, default_factory=OrderedDict, hash=False)
 
     def __post_init__(self) -> None:
         if self.db is not None:
             self.db.isolation_level = None
-            return_annotation = inspect.signature(self.fn).return_annotation
-            if not hasattr(return_annotation, '__name__'):
-                object.__setattr__(self, 'db_eval_types', dict(self.fn.__globals__))
-            else:
-                object.__setattr__(
-                    self,
-                    'db_eval_types',
-                    {**self.fn.__globals__, return_annotation.__name__: return_annotation}
-                )
 
             self.db.execute(dedent(f'''
                 CREATE TABLE IF NOT EXISTS `{self.table_name}` (
@@ -101,7 +92,7 @@ class _MemoizeBase:
             ).fetchall():
                 memo = self.make_memo(fn=self.fn, t0=t0)
                 memo.memo_return_state.called = True
-                (memo.memo_return_state.value,) = eval(v, self.db_eval_types)
+                memo.memo_return_state.value = pickle.loads(v)
                 self.memos[k] = memo
             if self.duration:
                 for k, t0 in self.db.execute(
@@ -177,8 +168,7 @@ class _MemoizeBase:
             raise memo.memo_return_state.value
         else:
             if (self.db is not None) and (self.memos[key] is memo):
-                value = str((memo.memo_return_state.value,))
-                assert (memo.memo_return_state.value,) == eval(value, self.db_eval_types)
+                value = pickle.dumps(memo.memo_return_state.value)
                 self.db.execute(
                     dedent(f'''
                         INSERT OR REPLACE INTO `{self.table_name}`
@@ -543,7 +533,7 @@ class _Memoize:
 
         - Values can persist to disk and be reloaded when memoize is initialized again.
 
-            @memoize(db=True)
+            @memoize(db_path=Path.home() / '.memoize')
             def foo(a) -> Any: ...
 
             foo(1)  # Function actually called. Result cached.
@@ -551,53 +541,24 @@ class _Memoize:
             # Process is restarted. Upon restart, the state of the memoize decorator is reloaded.
 
             foo(1)  # Function not called. Cached result returned.
-
-        - Be careful with 'db' and memoize values that don't hash consistently upon process restart.
-
-            class Foo:
-                @classmethod
-                @memoize(db=True)
-                def bar(cls, a) -> Any: ...
-
-            Foo.bar(1)  # Function actually called. Result cached.
-            Foo.bar(1)  # Function not called. Cached result returned.
-
-            # Process is restarted. Upon restart, the state of the memoize decorator is reloaded.
-
-            # Hash value of 'cls', is now different.
-            Foo.bar(1)  # Function actually called. Result cached.
-
-            # You can create a consistent hash key to avoid this.
-            class Foo:
-                @classmethod
-                @memoize(db=True, keygen=lambda cls, a: (f'{cls.__package__}:{cls.__name__}', a))
-                def bar(cls, a) -> Any: ...
-
-        - Alternative location of 'db' can also be given as pathlib.Path or str.
-            @memoize(db=Path.home() / 'foo_memoize')
-            def foo() -> Any: ...
-
-            @memoize(db='~/bar_memoize')
-            def bar() -> Any: ...
     """
 
-    _default_db_path = Path.home() / '.memoize'
     _all_decorators = WeakSet()
 
     @staticmethod
     def __call__(
             _decoratee: Optional[Decoratee] = None,
             *,
-            db: Union[bool, Path, str] = False,
+            db_path: Optional[Path] = None,
             duration: Optional[Union[int, float, timedelta]] = None,
             keygen: Optional[Keygen] = None,
             size: Optional[int] = None,
     ):
         if _decoratee is None:
-            return partial(memoize, db=db, duration=duration, keygen=keygen, size=size)
+            return partial(memoize, db_path=db_path, duration=duration, keygen=keygen, size=size)
 
         if inspect.isclass(_decoratee):
-            assert not db, 'Class memoization not allowed with db.'
+            assert db_path is None, 'Class memoization not allowed with db.'
 
             class WrappedMeta(type(_decoratee)):
                 # noinspection PyMethodParameters
@@ -610,14 +571,7 @@ class _Memoize:
 
             return type(_decoratee.__name__, (Wrapped,), {'__doc__': _decoratee.__doc__})
 
-        if isinstance(db, (str, Path)):
-            db = connect(f'{db}')
-        elif isinstance(db, bool):
-            if db:
-                db = connect(f'{_Memoize._default_db_path}')
-            else:
-                db = None
-
+        db = connect(f'{db_path}') if db_path is not None else None
         duration = timedelta(seconds=duration) if isinstance(duration, (int, float)) else duration
         assert (duration is None) or (duration.total_seconds() > 0)
         assert (size is None) or (size > 0)
@@ -650,9 +604,5 @@ class _Memoize:
         for decorator in _Memoize._all_decorators:
             decorator.memoize.reset()
 
-    @staticmethod
-    def set_default_db_path(path: Union[Path, str]) -> None:
-        _Memoize._default_db_path = Path(f'{path}')
-
 
 memoize = _Memoize()
